@@ -1,9 +1,8 @@
-require "rbconfig"
-require 'test/unit'
-require 'puma/cli'
-require 'tempfile'
+require_relative "helper"
 
-class TestCLI < Test::Unit::TestCase
+require "puma/cli"
+
+class TestCLI < Minitest::Test
   def setup
     @environment = 'production'
     @tmp_file = Tempfile.new("puma-test")
@@ -45,15 +44,11 @@ class TestCLI < Test::Unit::TestCase
     cli = Puma::CLI.new ["-b", "tcp://127.0.0.1:9876",
                          "--control", url,
                          "--control-token", "",
-                         "test/lobster.ru"], @events
+                         "test/rackup/lobster.ru"], @events
 
-    thread_exception = nil
     t = Thread.new do
-      begin
-        cli.run
-      rescue Exception => e
-        thread_exception = e
-      end
+      Thread.current.abort_on_exception = true
+      cli.run
     end
 
     wait_booted
@@ -61,14 +56,13 @@ class TestCLI < Test::Unit::TestCase
     s = TCPSocket.new "127.0.0.1", 9877
     s << "GET /stats HTTP/1.0\r\n\r\n"
     body = s.read
-    assert_equal '{ "backlog": 0, "running": 0 }', body.split("\r\n").last
+    assert_equal '{ "backlog": 0, "running": 0 }', body.split(/\r?\n/).last
 
     cli.launcher.stop
     t.join
-    assert_equal nil, thread_exception
   end
 
-  unless defined?(JRUBY_VERSION) || RbConfig::CONFIG["host_os"] =~ /mingw|mswin/
+  unless Puma.jruby? || Puma.windows?
   def test_control_clustered
     url = "unix://#{@tmp_path}"
 
@@ -77,18 +71,23 @@ class TestCLI < Test::Unit::TestCase
                          "-w", "2",
                          "--control", url,
                          "--control-token", "",
-                         "test/lobster.ru"], @events
+                         "test/rackup/lobster.ru"], @events
 
     t = Thread.new { cli.run }
     t.abort_on_exception = true
 
     wait_booted
 
+    sleep 2
+
     s = UNIXSocket.new @tmp_path
     s << "GET /stats HTTP/1.0\r\n\r\n"
     body = s.read
 
-    assert_match(/\{ "workers": 2, "phase": 0, "booted_workers": 0, "old_workers": 0, "worker_status": \[\{ "pid": \d+, "index": 0, "phase": 0, "booted": false, "last_checkin": "[^"]+", "last_status": \{\} \},\{ "pid": \d+, "index": 1, "phase": 0, "booted": false, "last_checkin": "[^"]+", "last_status": \{\} \}\] \}/, body.split("\r\n").last)
+    require 'json'
+    status = JSON.parse(body.split("\n").last)
+
+    assert_equal 2, status["workers"]
 
     # wait until the first status ping has come through
     sleep 6
@@ -107,7 +106,7 @@ class TestCLI < Test::Unit::TestCase
     cli = Puma::CLI.new ["-b", "unix://#{@tmp_path2}",
                          "--control", url,
                          "--control-token", "",
-                         "test/lobster.ru"], @events
+                         "test/rackup/lobster.ru"], @events
 
     t = Thread.new { cli.run }
     t.abort_on_exception = true
@@ -130,7 +129,7 @@ class TestCLI < Test::Unit::TestCase
     cli = Puma::CLI.new ["-b", "unix://#{@tmp_path2}",
                          "--control", url,
                          "--control-token", "",
-                         "test/lobster.ru"], @events
+                         "test/rackup/lobster.ru"], @events
 
     t = Thread.new { cli.run }
     t.abort_on_exception = true
@@ -146,6 +145,60 @@ class TestCLI < Test::Unit::TestCase
     t.join
   end
 
+  def test_control_gc_stats
+    url = "unix://#{@tmp_path}"
+
+    cli = Puma::CLI.new ["-b", "unix://#{@tmp_path2}",
+                         "--control", url,
+                         "--control-token", "",
+                         "test/rackup/lobster.ru"], @events
+
+    t = Thread.new { cli.run }
+    t.abort_on_exception = true
+
+    wait_booted
+
+    s = UNIXSocket.new @tmp_path
+    s << "GET /gc-stats HTTP/1.0\r\n\r\n"
+    body = s.read
+    s.close
+
+    lines = body.split("\r\n")
+    json_line = lines.detect { |l| l[0] == "{" }
+    pairs = json_line.scan(/\"[^\"]+\": [^,]+/)
+    gc_stats = {}
+    pairs.each do |p|
+      p =~ /\"([^\"]+)\": ([^,]+)/ || raise("Can't parse #{p.inspect}!")
+      gc_stats[$1] = $2
+    end
+    gc_count_before = gc_stats["count"].to_i
+
+    s = UNIXSocket.new @tmp_path
+    s << "GET /gc HTTP/1.0\r\n\r\n"
+    body = s.read # Ignored
+    s.close
+
+    s = UNIXSocket.new @tmp_path
+    s << "GET /gc-stats HTTP/1.0\r\n\r\n"
+    body = s.read
+    s.close
+    lines = body.split("\r\n")
+    json_line = lines.detect { |l| l[0] == "{" }
+    pairs = json_line.scan(/\"[^\"]+\": [^,]+/)
+    gc_stats = {}
+    pairs.each do |p|
+      p =~ /\"([^\"]+)\": ([^,]+)/ || raise("Can't parse #{p.inspect}!")
+      gc_stats[$1] = $2
+    end
+    gc_count_after = gc_stats["count"].to_i
+
+    # Hitting the /gc route should increment the count by 1
+    assert_equal gc_count_before + 1, gc_count_after
+
+    cli.launcher.stop
+    t.join
+  end
+
   def test_tmp_control
     url = "tcp://127.0.0.1:8232"
     cli = Puma::CLI.new ["--state", @tmp_path, "--control", "auto"]
@@ -167,10 +220,7 @@ class TestCLI < Test::Unit::TestCase
                           "--state", @tmp_path ]
     cli.launcher.write_state
 
-    data = nil
-    assert_nothing_raised do
-      data = YAML.load_file( @tmp_path )
-    end
+    data = YAML.load_file(@tmp_path)
 
     keys_not_stripped = data.keys & Puma::CLI::KEYS_NOT_TO_PERSIST_IN_STATE
     assert_empty keys_not_stripped
