@@ -1,12 +1,4 @@
-require "rbconfig"
-require 'test/unit'
-require 'socket'
-require 'openssl'
-
-require 'puma/minissl'
-require 'puma/server'
-
-require 'net/https'
+require_relative "helper"
 
 class SSLEventsHelper < ::Puma::Events
   attr_accessor :addr, :cert, :error
@@ -26,7 +18,7 @@ DISABLE_SSL = begin
               false
             end
 
-class TestPumaServerSSL < Test::Unit::TestCase
+class TestPumaServerSSL < Minitest::Test
 
   def setup
     return if DISABLE_SSL
@@ -37,7 +29,7 @@ class TestPumaServerSSL < Test::Unit::TestCase
 
     @ctx = Puma::MiniSSL::Context.new
 
-    if defined?(JRUBY_VERSION)
+    if Puma.jruby?
       @ctx.keystore =  File.expand_path "../../examples/puma/keystore.jks", __FILE__
       @ctx.keystore_pass = 'blahblah'
     else
@@ -114,25 +106,23 @@ class TestPumaServerSSL < Test::Unit::TestCase
     assert_equal "https", body
   end
 
-  unless RUBY_VERSION =~ /^1.8/
-    def test_ssl_v3_rejection
-      return if DISABLE_SSL
-      @http.ssl_version='SSLv3'
-      assert_raises(OpenSSL::SSL::SSLError) do
-        @http.start do
-          Net::HTTP::Get.new '/'
-        end
-      end
-      unless defined?(JRUBY_VERSION)
-        assert_match("wrong version number", @events.error.message) if @events.error
+  def test_ssl_v3_rejection
+    return if DISABLE_SSL
+    @http.ssl_version='SSLv3'
+    assert_raises(OpenSSL::SSL::SSLError) do
+      @http.start do
+        Net::HTTP::Get.new '/'
       end
     end
+    unless Puma.jruby?
+      assert_match("wrong version number", @events.error.message) if @events.error
+    end
   end
 
 end
 
 # client-side TLS authentication tests
-class TestPumaServerSSLClient < Test::Unit::TestCase
+class TestPumaServerSSLClient < Minitest::Test
 
   def assert_ssl_client_error_match(error, subject=nil, &blk)
     @port = 3212
@@ -141,7 +131,7 @@ class TestPumaServerSSLClient < Test::Unit::TestCase
     @app = lambda { |env| [200, {}, [env['rack.url_scheme']]] }
 
     @ctx = Puma::MiniSSL::Context.new
-    if defined?(JRUBY_VERSION)
+    if Puma.jruby?
       @ctx.keystore =  File.expand_path "../../examples/puma/client-certs/keystore.jks", __FILE__
       @ctx.keystore_pass = 'blahblah'
     else
@@ -176,7 +166,7 @@ class TestPumaServerSSLClient < Test::Unit::TestCase
     assert_equal !!error, client_error
     # The JRuby MiniSSL implementation lacks error capturing currently, so we can't inspect the
     # messages here
-    unless defined?(JRUBY_VERSION)
+    unless Puma.jruby?
       assert_match error, events.error.message if error
       assert_equal @host, events.addr if error
       assert_equal subject, events.cert.subject.to_s if subject
