@@ -1,14 +1,6 @@
-require "rbconfig"
-require 'test/unit'
-require 'socket'
-require 'openssl'
+require_relative "helper"
 
-require 'puma/minissl'
-require 'puma/server'
-
-require 'net/https'
-
-class TestTCPRack < Test::Unit::TestCase
+class TestTCPRack < Minitest::Test
 
   def setup
     @port = 3212
